@@ -1,55 +1,25 @@
 package Mojo::DOM::Role::Analyzer ;
-$Mojo::DOM::Role::Analyzer::VERSION = '0.011';
+$Mojo::DOM::Role::Analyzer::VERSION = '0.012';
 use strict;
 use warnings;
 use Role::Tiny;
 use Carp;
 
+use overload "cmp" => sub { $_[0]->compare(@_) }, fallback => 1;
+
+# wrap the find method so we can call the common method on collections
 around find => sub {
   my $orig = shift;
   my $self = shift;
   return $self->$orig(@_)->with_roles('+Extra');
 };
 
-use overload "cmp" => sub { $_[0]->compare(@_) }, fallback => 1;
-
-sub element_count {
-  my $self = shift;
-  return $self->descendant_nodes->grep(sub { $_->type eq 'tag' })->size;
-}
-
-sub _get_selectors {
-  my ($s, $sel1, $sel2);
-  if (!$_[2]) {
-    $s = shift;
-    $sel1 = $s->selector;
-    if (ref $_[0]) {
-      $sel2 = $_[0]->selector;
-    } else {
-      $sel2 = $s->root->at($_[0])->selector;
-    }
-  } else {
-    $s = $_[0];
-    $sel1 = $_[1]->selector;
-    $sel2 = $_[2]->selector;
-  }
-  return ($s, $sel1, $sel2);
-}
-
-sub is_ancestor_to {
-  my $s = shift;
-  my $arg = shift;
-  my $sel1 = $s->selector;
-  my $sel2 = $arg->selector;
-
-  return $sel2 =~ /^\Q$sel1\E/ ? 1 : 0;
-}
-
 # traverses the DOM upward to find the closest tag node
 sub closest_up {
   return _closest(@_, 'up');
 }
 
+# traverses the DOM downward to find the closest tag node
 sub closest_down {
   return _closest(@_, 'down');
 }
@@ -90,6 +60,57 @@ sub _closest {
 
 }
 
+# find the common ancestor between a node and another node or group of nodes
+sub common {
+# uncomment to debug
+# use Log::Log4perl::Shortcuts qw(:all); # for development only
+#  if (ref $_[0]) { logd ref $_[0]; } else { logd $_[0]; }
+#  if (ref $_[1]) { logd ref $_[1]; } else { logd $_[1]; }
+#  if (ref $_[2]) { logd ref $_[2]; } else { logd $_[2]; }
+
+   # The argument handling is a bit confusing. Keep these important notes in mind while reading this code:
+
+   # 1) This method is called on Mojo::DOM objects (obviously)
+   # 2) Don't confuse this method with its sister method also named "common"
+   #    in Mojo::DOM::Collection::Extra which works with Mojo::Collection objects
+   # 3) The argument handling below works for the different types of common syntaxes noted
+   #    below in the comments.
+
+  my ($s, $sel1, $sel2);
+
+  # function-like use of common: $dom->commont($dom1, $dom2)
+  if (ref $_[1] && ref $_[2]) {
+    $s = $_[0];
+    $sel1 = $_[1]->selector;
+    $sel2 = $_[2]->selector;
+  # DWIM syntax handling
+  } else {
+    if (!$_[1] && !$_[2]) {                         # $dom->at('div');
+      my $s = shift;
+      return $s->root->find($s->selector)->common;
+    } elsif ($_[1] && !ref $_[1] && !$_[2]) {       # $dom->at('div.first')->common('p');
+      $s = shift;
+      $sel1 = $s->selector;
+      $sel2 = $s->root->at(shift)->selector;
+    }
+  }
+
+  my @t1_path = split / > /, $sel1;
+  my @t2_path = split / > /, $sel2;
+
+  my @common_path;
+  foreach my $seg (@t1_path) {
+    my $seg2 = shift @t2_path;
+    last if !$seg2 || $seg ne $seg2;
+    push @common_path, $seg2;
+  }
+
+  my $common_selector = join ' > ', @common_path;
+
+  return $s->root->at($common_selector);
+
+}
+
 # determine if a tag A comes before or after tag B in the dom
 sub compare {
   my ($s, $sel1, $sel2) = _get_selectors(@_);
@@ -135,62 +156,72 @@ sub deepest {
   return $deepest_depth;
 }
 
-sub common_parent_within {
-  my $s = shift;
-  my $sel = $s->selector;
-  $s = $s->root->at($_[0]);
-  $s->common($sel);
+sub element_count {
+  my $self = shift;
+  return $self->descendant_nodes->grep(sub { $_->type eq 'tag' })->size;
 }
 
-# find the common ancestor between a node and another node or group of nodes
-sub common {
-# uncomment to debug
-# use Log::Log4perl::Shortcuts qw(:all); # for development only
-#  if (ref $_[0]) { logd ref $_[0]; } else { logd $_[0]; }
-#  if (ref $_[1]) { logd ref $_[1]; } else { logd $_[1]; }
-#  if (ref $_[2]) { logd ref $_[2]; } else { logd $_[2]; }
+# determine if one node is an ancestor to another
+sub is_ancestor_to {
+  my $s = shift;
+  my $arg = shift;
+  my $sel1 = $s->selector;
+  my $sel2 = $arg->selector;
 
-   # The argument handling is a bit confusing. Keep these important notes in mind while reading this code:
+  return $sel2 =~ /^\Q$sel1\E/ ? 1 : 0;
+}
 
-   # 1) This method is called on Mojo::DOM objects (obviously)
-   # 2) Don't confuse this mthod with its sister method also named "common"
-   #    in Mojo::DOM::Collection::Extra which works with Mojo::Collection objects
-   # 3) The argument handling below works for the different types of common syntaxes noted
-   #    below in the comments.
+sub tag_analysis {
+  my $s        = shift;
+  my $selector = shift;
 
+  carp "A selector argument must be passed to the tag_analysis method"
+    unless $selector;
+
+  my @sub_enclosing_nodes = $s->_tag_analysis_helper($selector);
+
+  foreach my $sn (@sub_enclosing_nodes) {
+    next if $sn->{all_tags_have_same_depth};
+    my $ec = $s->at($sn->{selector})->common($selector);
+    my @enclosing_nodes = $ec->_tag_analysis_helper($selector);
+    push @sub_enclosing_nodes, @enclosing_nodes;
+  }
+
+  # cleanup any unnecessary nodes at top of the array wrapping the smallest enconpassing dom
+  my $total_tags = $s->find($selector)->size;
+  my $number_of_tags = grep { $_->{size} == $total_tags } @sub_enclosing_nodes;
+  splice @sub_enclosing_nodes, 0, $number_of_tags - 1;
+
+  return @sub_enclosing_nodes;
+}
+
+sub _tag_analysis_helper {
+  my $s        = shift;
+  my $selector = shift;
+  my @sub_enclosing_nodes = shift;
+
+  carp "A selector argument must be passed to the tag_analysis method"
+    unless $selector;
+
+  return _gsec($s, $selector);
+}
+
+sub _get_selectors {
   my ($s, $sel1, $sel2);
-
-  # function-like use of common: $dom->commont($dom1, $dom2)
-  if (ref $_[1] && ref $_[2]) {
+  if (!$_[2]) {
+    $s = shift;
+    $sel1 = $s->selector;
+    if (ref $_[0]) {
+      $sel2 = $_[0]->selector;
+    } else {
+      $sel2 = $s->root->at($_[0])->selector;
+    }
+  } else {
     $s = $_[0];
     $sel1 = $_[1]->selector;
     $sel2 = $_[2]->selector;
-  # DWIM syntax handling
-  } else {
-    if (!$_[1] && !$_[2]) {                         # $dom->at('div');
-      my $s = shift;
-      return $s->root->find($s->selector)->common;
-    } elsif ($_[1] && !ref $_[1] && !$_[2]) {       # $dom->at('div.first')->common('p');
-      $s = shift;
-      $sel1 = $s->selector;
-      $sel2 = $s->root->at(shift)->selector;
-    }
   }
-
-  my @t1_path = split / > /, $sel1;
-  my @t2_path = split / > /, $sel2;
-
-  my @common_path;
-  foreach my $seg (@t1_path) {
-    my $seg2 = shift @t2_path;
-    last if !$seg2 || $seg ne $seg2;
-    push @common_path, $seg2;
-  }
-
-  my $common_selector = join ' > ', @common_path;
-
-  return $s->root->at($common_selector);
-
+  return ($s, $sel1, $sel2);
 }
 
 # get secondary enclosing tags
@@ -233,41 +264,6 @@ sub _gsec {
   return @sub_enclosing_nodes;
 }
 
-sub tag_analysis {
-  my $s        = shift;
-  my $selector = shift;
-
-  carp "A selector argument must be passed to the tag_analysis method"
-    unless $selector;
-
-  my @sub_enclosing_nodes = $s->_tag_analysis_helper($selector);
-
-  foreach my $sn (@sub_enclosing_nodes) {
-    next if $sn->{all_tags_have_same_depth};
-    my $ec = $s->at($sn->{selector})->common($selector);
-    my @enclosing_nodes = $ec->_tag_analysis_helper($selector);
-    push @sub_enclosing_nodes, @enclosing_nodes;
-  }
-
-  # cleanup any unnecessary nodes at top of the array wrapping the smallest enconpassing dom
-  my $total_tags = $s->find($selector)->size;
-  my $number_of_tags = grep { $_->{size} == $total_tags } @sub_enclosing_nodes;
-  splice @sub_enclosing_nodes, 0, $number_of_tags - 1;
-
-  return @sub_enclosing_nodes;
-}
-
-sub _tag_analysis_helper {
-  my $s        = shift;
-  my $selector = shift;
-  my @sub_enclosing_nodes = shift;
-
-  carp "A selector argument must be passed to the tag_analysis method"
-    unless $selector;
-
-  return _gsec($s, $selector);
-}
-
 
 1; # Magic true value
 # ABSTRACT: miscellaneous methods for analyzing a DOM
@@ -389,9 +385,10 @@ is calculated.
   my $common = $dom->at('p.foo')->common;
 
 Returns the lowest common ancestor node between two nodes or
-betwween a node and a group of nodes sharing the same selector.
+between a node and a group of nodes sharing the same selector.
 
-See L<Mojo::Collection::Role::Extra/common> for a similar method that is on Mojo::Collections.
+See L<Mojo::Collection::Role::Extra/common> for a similar method that invoked
+on Mojo::Collection objects.
 
 =head3 compare
 
@@ -482,7 +479,7 @@ with the following information for each of the enclosing nodes:
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
